@@ -14,6 +14,12 @@ class FieldABC(object):
     #: The field's name.
     name = None
 
+    def serialize(self, attr, obj, accessor=None):
+        raise NotImplementedError
+
+    def deserialize(self, value):
+        raise NotImplementedError
+
     def _serialize(self, value, key, obj):
         raise NotImplementedError
 
@@ -24,11 +30,6 @@ class FieldABC(object):
         ret = copy.copy(self)
         return ret
 
-    def __repr__(self):
-        return '<{0} Field>'.format(self.__class__.__name__)
-
-    __str__ = __repr__
-
 
 class SchemaABC(object):
     """Abstract base class from which all Schemas inherit."""
