@@ -297,6 +297,8 @@ def _get_value_for_keys(keys, obj, default):
 
 
 def _get_value_for_key(key, obj, default):
+    if isinstance(obj, dict):
+        return obj.get(key, default)
     if isinstance(key, basestring) and hasattr(obj, key):
         return getattr(obj, key)
     if is_indexable_but_not_string(obj):
